Learn R Programming

cond (version 1.2-2)

family.cond: Use family() on a ``cond'' object

Description

This is a method for the function family() for objects inheriting from class cond. See family for the general behaviour of this function.

Usage

## S3 method for class 'cond':
family(object, \dots)

Arguments

object
any object from which a family object can be extracted.
...
absorbs any additional argument.

See Also

family